;;; @Package     octave.scm
;;; @Subtitle    A simple interface to GNU/Octave
;;; @HomePage    http://carretechnologies.com/octave-egg/
;;; @Author      Pierre-Alexandre Fournier
;;; @AuthorEmail octave-egg@@carretechnologies.com
;;; @Version     0.4
;;; @Date        September 17th 2007

;; $Id:  $


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Octave interface version
(define (octave:version) "0.4")


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Octave ports and pid
(define octave:input-port  #f)
(define octave:output-port #f)
(define octave:pid         #f)


;;; Compatibility layer for Chicken and Gambit
(cond-expand
 ;;;;;;;;;;;;;;;;;;;;;; Chicken ;;;;;;;;;;;;;;;;;;;;;;;
 (chicken
  (declare (export 
	    ;; base variables and functions
	    octave:version
	    octave:input-port
	    octave:output-port
	    octave:pid
	    octave:start
	    octave:stop
	    octave:send
	    ;; 2d plot functions
	    octave:plot
	    octave:semilogx
	    octave:semilogy
	    octave:loglog
	    octave:polar
	    octave:bar
	    octave:mesh-xyz
	    ;; 3d plot functions
	    octave:mesh
	    octave:contour
	    octave:imagesc
	    ;; Labels
	    octave:title
	    octave:xlabel
	    octave:ylabel
	    octave:legend
	    octave:grid
	    ;; Other
	    octave:figure
	    octave:replot
	    ;; Files
	    octave:supported-file-types
	    octave:save-plot-to
	    ))

  (use posix)
  ;;; Start octave process
  (define (octave:start)
    (let-values ((octave:process-info (process "octave -q")))
		(set! octave:input-port  (car   octave:process-info))
		(set! octave:output-port (cadr  octave:process-info))
		(set! octave:pid         (caddr octave:process-info))))


  ;;; Stop octave process
  (define (octave:stop)
    (octave:send "quit")
    (set! octave:input-port  #f)
    (set! octave:output-port #f)
    (set! octave:pid         #f))
  ;;; Send a command to Octave
  (define (octave:send str)
    (cond ((not octave:output-port)
	   (error "Octave process not started. Start it with (octave:start).\n"))
	  (else
	   (display str octave:output-port))))
  );;; End Chicken

 ;;;;;;;;;;;;;;;;;;;;;; Gambit ;;;;;;;;;;;;;;;;;;;;;;;
 (gambit
  (define (conc . objs)
    (with-output-to-string 
      "" (lambda () (display objs))))

  (define (string-intersperse lst between)
    (if (or (null? lst) 
	    (null? (cdr lst))) 
	lst
	(cons (car lst)
	      (cons between 
		    (string-intersperse (cdr lst) between)))))

  ;;; Start octave process
  (define (octave:start)
    (set! octave:input-port  
	  (open-process (list path: "octave"
			      arguments: (list "-q"))))
    (set! octave:output-port octave:input-port)
    (set! octave:pid         #t))

  ;;; Stop octave process
  (define (octave:stop)
    (octave:send "quit")
    (close-input-port  octave:input-port)
    (close-output-port octave:output-port)
    (set! octave:input-port  #f)
    (set! octave:output-port #f)
    (set! octave:pid         #f))

  ;;; Send a command to Octave
  (define (octave:send str)
    (cond ((not octave:output-port)
	   (error "Octave process not started. Start it with (octave:start).\n"))
	  (else
	   (display str octave:output-port)
	   (force-output octave:output-port))))
  ));;; End Gambit


(define (octave:restart)
  (octave:stop)
  (octave:start))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; some utilities
(define (list->octave-vector lst)
  (conc "[" (string-intersperse (map conc lst) " ") "]"))

(define (list->octave-matrix lst)
  (conc "[" (string-intersperse (map list->octave-vector lst) "; ") "]"))

;;; verify arguments length for 2d plots
(define (assert-args-lengths args)  
  (cond ((null? args)
	 #t)
	((null? (cdr args))
	 #t)
	((string? (cadr args))
	 (assert-args-lengths (cddr args)))
	((and (> (length args) 3)
	      (string? (caddr args))
	      (= (length (car  args))
		 (length (cadr args))))
	 (assert-args-lengths (cdddr args)))
	((= (length (car  args))
	    (length (cadr args)))
	 (assert-args-lengths (cddr args)))
	(else
	 #f)))

(define (args->comma-separated-octave-vectors args)
  (let ((octave-vectors
	 (map (lambda (arg)
		(cond ((list? arg)
		       (list->octave-vector arg))
		      (else
		       (conc arg))))
	      args)))
    (string-intersperse octave-vectors ", ")))

(define (args->comma-separated-octave-matrixes args)
  (let ((octave-vectors
	 (map (lambda (arg)
		(cond ((list? arg)
		       (map list->octave-matrix args))
		      (else
		       (conc arg))))
	      args)))
    (string-intersperse octave-vectors ", ")))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Plots

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; graph lists of numbers in gnuplot using a 2d plot function (e.g.:
;;; "plot", "loglog", "semilogx")
(define (octave:generic-2dplot plot-function args)
  (cond ((null? args)
         #f)
        ((not (assert-args-lengths args))
	 (error "vector lengths must match"))
	(else
         (octave:send
          (conc plot-function
                "(" (args->comma-separated-octave-vectors args) ");\n")))))

;;; some 2d plot functions
(define (octave:plot     . args) (octave:generic-2dplot "plot"     args))
(define (octave:semilogx . args) (octave:generic-2dplot "semilogx" args))
(define (octave:semilogy . args) (octave:generic-2dplot "semilogy" args))
(define (octave:loglog   . args) (octave:generic-2dplot "loglog"   args))
(define (octave:polar    . args) (octave:generic-2dplot "polar"    args))
(define (octave:bar      . args) (octave:generic-2dplot "bar"      args))
;;; stairs is similar to bar
(define (octave:stairs   . args) (octave:generic-2dplot "stairs"   args))

(define (octave:errorbar . args) (octave:generic-2dplot "errorbar" args))


(define (octave:mesh-xyz . args)
  (octave:send
   (conc "mesh "
	  "(" (args->comma-separated-octave-vectors 
	       (take args 2))
	  "," (args->comma-separated-octave-matrixes 
	       (list (list-ref args 2)))
	  ");\n")))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; graph lists of lists of numbers in gnuplot using a 3d plot
;;; function (e.g.: "mesh")
(define (octave:generic-3dplot plot-function args)
  (cond
   ((null? args)
    #f)
   (else
    (octave:send
     (conc plot-function
           "(" (args->comma-separated-octave-matrixes args) ");\n")))))

;;; some 3d plot functions
(define (octave:mesh     . args) (octave:generic-3dplot "mesh"     args))
(define (octave:contour  . args) (octave:generic-3dplot "contour"  args))
(define (octave:imagesc  . args) (octave:generic-3dplot "imagesc"  args))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; new octave figure
(define (octave:figure)  (octave:send "figure;\n"))

;;; close all figures
(define (octave:close)  (octave:send "close;\n"))
(define (octave:close-all)  (octave:send "close all;\n"))

;;; example of wrapper function
(define (octave:vct-plot . args)
  (apply octave:plot (map vct->list args)))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Labels

;;; title, x and y labels
(define (octave:title  title)  (octave:send (conc "title('"  title  "');\n")))
(define (octave:xlabel xlabel) (octave:send (conc "xlabel('" xlabel "');\n")))
(define (octave:ylabel ylabel) (octave:send (conc "ylabel('" ylabel "');\n")))

;;; legend only works with plot, bar
(define (octave:legend . args) 
  (define (quote-args args)
    (conc (string-intersperse
	   (map (lambda (s) (conc "'" s "'")) args)
	   ", ")))
  (octave:send (conc "legend(" (quote-args args) ");\n")))

;;; grid on/off
(define (octave:grid . args)
  (let ((off? (cond ((and (not (null? args)) 
                          (string=? (car args) "off"))
                     "off")
                    (else
                     ""))))
    (octave:send (conc "grid " off? ";\n"))))

;;; replot
(define (octave:replot)  
  (octave:send "replot;\n"))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; GNUPLOT output file types

;;; set plot output
(define (octave:set-terminal! output)
  ;;; __gnuplot_set__ is an internal Octave function that replaces
  ;;; gset (gset is deprecated)
  (octave:send (conc "__gnuplot_set__ terminal " output ";\n")))

;;; reset plot output
(define (octave:reset-terminal!) (octave:set-terminal! "x11"))

;;; set output
(define (octave:set-output! output)
  (octave:send (conc "__gnuplot_set__ output " output ";\n")))

;;; set output file
(define (octave:set-output-file! filename)
  (octave:set-output! (conc "'" filename "'")))

(define (octave:reset-output!)
  (octave:set-output! ""))

;;; All File Types supported by gnuplot 4.0 patchlevel 0
(define octave:supported-file-types
  (list
   "aed512" ;;  AED 512 Terminal
   "aed767" ;;  AED 767 Terminal
   "aifm" ;;  Adobe Illustrator 3.0 Format
   "bitgraph" ;;  BBN Bitgraph Terminal
   "cgm" ;;  Computer Graphics Metafile
   "corel" ;;  EPS format for CorelDRAW
   "dumb" ;;  printer or glass dumb terminal
   "dxf" ;;  dxf-file for AutoCad (default size 120x80)
   "eepic" ;;  EEPIC -- extended LaTeX picture environment
   "emf" ;;  Enhanced Metafile format
   "emtex" ;;  LaTeX picture environment with emTeX specials
   "epslatex" ;;  LaTeX (Text) and encapsulated PostScript
   "epson" ;;_180dpi  Epson LQ-style 180-dot per inch (24 pin) printers
   "epson" ;;_60dpi  Epson-style 60-dot per inch printers
   "epson" ;;_lx800  Epson LX-800, Star NL-10, NX-1000, PROPRINTER ...
   "fig" ;;  FIG graphics language for XFIG graphics editor
   "gif" ;;  GIF format [mode] [fontsize] [size] [colors]
   "gpic" ;;  GPIC -- Produce graphs in groff using the gpic preprocessor
   "hp2623A" ;;  HP2623A and maybe others
   "hp2648" ;;  HP2648 and HP2647
   "hp500c" ;;  HP DeskJet 500c, [75 100 150 300] [rle tiff]
   "hpdj" ;;  HP DeskJet 500, [75 100 150 300]
   "hpgl" ;;  HP7475 and relatives [number of pens] [eject]
   "hpljii" ;;  HP Laserjet series II, [75 100 150 300]
   "hppj" ;;  HP PaintJet and HP3630 [FNT5X9 FNT9X17 FNT13X25]
   "imagen" ;;  Imagen laser printer
   "jpeg" ;;  JPEG images using libgd and TrueType fonts
   "kc"	;;_tek40xx  MS-DOS Kermit Tek4010 terminal emulator - color
   "km"	;;_tek40xx  MS-DOS Kermit Tek4010 terminal emulator - monochrome
   "latex" ;;  LaTeX picture environment
   "mf"	;;  Metafont plotting standard
   "mif" ;;  Frame maker MIF 3.00 format
   "mp"	;;  MetaPost plotting standard
   "nec" ;;_cp6  NEC printer CP6, Epson LQ-800 [monocrome color draft]
   "okidata" ;;  OKIDATA 320/321 Standard
   "pbm" ;;  Portable bitmap [small medium large] [monochrome gray color]
   "pcl5" ;;  HP Designjet 750C, HP Laserjet III/IV, etc. (many options)
   "png" ;;  PNG images using libgd and TrueType fonts
   "postscript"	;;  PostScript graphics language [mode "fontname" font_size]
   "pslatex" ;;  LaTeX picture environment with PostScript \specials
   "pstex" ;;  plain TeX with PostScript \specials
   "pstricks" ;;  LaTeX picture environment with PSTricks macros
   "qms" ;;  QMS/QUIC Laser printer (also Talaris 1200 and others)
   "regis" ;;  REGIS graphics language
   "selanar" ;;  Selanar
   "starc" ;;  Star Color Printer
   "svg" ;;  W3C Scalable Vector Graphics driver
   "table" ;;  Dump ASCII table of X Y [Z] values to output
   "tandy" ;;_60dpi  Tandy DMP-130 series 60-dot per inch graphics
   "tek40xx" ;;  Tektronix 4010 and others; most TEK emulators
   "tek410x" ;;  Tektronix 4106, 4107, 4109 and 420X terminals
   "texdraw" ;;  LaTeX texdraw environment
   "tgif" ;;  TGIF X11 [mode] [x,y] [dashed] ["font" [fontsize]]
   "tkcanvas" ;;  Tk/Tcl canvas widget [perltk] [interactive]
   "tpic" ;;  TPIC -- LaTeX picture environment with tpic \specials
   "unknown" ;;  Unknown terminal type - not a plotting device
   "vttek" ;;  VT-like tek40xx terminal emulator
   "x11" ;;  X11 Window System
   "X11" ;;  X11 Window System (identical to x11)
   "xlib" ;;  X11 Window System (gnulib_x11 dump)
   ))

;;; Use this function to use available file types
(define (octave:save-plot-to type filename)
  (define (any proc lst)
    (cond ((null? lst)      #f)
	  ((proc (car lst)) #t)
	  (else
	   (any proc (cdr lst)))))
  
  (define (draw)
    (octave:set-output-file! filename)
    (octave:replot)
    (octave:set-output! "")
    (octave:reset-terminal!)
    #t)
  
  (cond ((any (lambda (s) (string=? type s))
	      octave:supported-file-types)
	 (octave:set-terminal! type)
	 (draw))
	(else
	 (error "File type not supported in Octave (see list defined
in octave:supported-file-types for supported types)."))))

;;; Shortcuts (not really necessary, I will probably remove them)
(define (octave:save-plot-to-png        filename) (octave:save-plot-to "png"        filename))
(define (octave:save-plot-to-postscript filename) (octave:save-plot-to "postscript" filename))
(define (octave:save-plot-to-gif        filename) (octave:save-plot-to "gif"        filename))
(define (octave:save-plot-to-jpeg       filename) (octave:save-plot-to "jpeg"       filename))


;;; OBSOLETE
;;;;; aed512  AED 512 Terminal
;;(define (octave:set-terminal-to-aed512!) (octave:set-terminal! "aed512"))
;;;;; aed767  AED 767 Terminal
;;(define (octave:set-terminal-to-aed767!) (octave:set-terminal! "aed767"))
;;;;; aifm  Adobe Illustrator 3.0 Format
;;(define (octave:set-terminal-to-aifm!) (octave:set-terminal! "aifm"))
;;;;; bitgraph  BBN Bitgraph Terminal
;;(define (octave:set-terminal-to-bitgraph!) (octave:set-terminal! "bitgraph"))
;;;;; cgm  Computer Graphics Metafile
;;(define (octave:set-terminal-to-cgm!) (octave:set-terminal! "cgm"))
;;;;; corel  EPS format for CorelDRAW
;;(define (octave:set-terminal-to-corel!) (octave:set-terminal! "corel"))
;;;;; dumb  printer or glass dumb terminal
;;(define (octave:set-terminal-to-dumb!) (octave:set-terminal! "dumb"))
;;;;; dxf  dxf-file for AutoCad (default size 120x80)
;;(define (octave:set-terminal-to-dxf!) (octave:set-terminal! "dxf"))
;;;;; eepic  EEPIC -- extended LaTeX picture environment
;;(define (octave:set-terminal-to-eepic!) (octave:set-terminal! "eepic"))
;;;;; emf  Enhanced Metafile format
;;(define (octave:set-terminal-to-emf!) (octave:set-terminal! "emf"))
;;;;; emtex  LaTeX picture environment with emTeX specials
;;(define (octave:set-terminal-to-emtex!) (octave:set-terminal! "emtex"))
;;;;; epslatex  LaTeX (Text) and encapsulated PostScript
;;(define (octave:set-terminal-to-epslatex!) (octave:set-terminal! "epslatex"))
;;;;; epson_180dpi  Epson LQ-style 180-dot per inch (24 pin) printers
;;(define (octave:set-terminal-to-epson!) (octave:set-terminal! "epson"))
;;;;; epson_60dpi  Epson-style 60-dot per inch printers
;;(define (octave:set-terminal-to-epson!) (octave:set-terminal! "epson"))
;;;;; epson_lx800  Epson LX-800, Star NL-10, NX-1000, PROPRINTER ...
;;(define (octave:set-terminal-to-epson!) (octave:set-terminal! "epson"))
;;;;; fig  FIG graphics language for XFIG graphics editor
;;(define (octave:set-terminal-to-fig!) (octave:set-terminal! "fig"))
;;;;; gif  GIF format [mode] [fontsize] [size] [colors]
;;(define (octave:set-terminal-to-gif!) (octave:set-terminal! "gif"))
;;;;; gpic  GPIC -- Produce graphs in groff using the gpic preprocessor
;;(define (octave:set-terminal-to-gpic!) (octave:set-terminal! "gpic"))
;;;;; hp2623A  HP2623A and maybe others
;;(define (octave:set-terminal-to-hp2623A!) (octave:set-terminal! "hp2623A"))
;;;;; hp2648  HP2648 and HP2647
;;(define (octave:set-terminal-to-hp2648!) (octave:set-terminal! "hp2648"))
;;;;; hp500c  HP DeskJet 500c, [75 100 150 300] [rle tiff]
;;(define (octave:set-terminal-to-hp500c!) (octave:set-terminal! "hp500c"))
;;;;; hpdj  HP DeskJet 500, [75 100 150 300]
;;(define (octave:set-terminal-to-hpdj!) (octave:set-terminal! "hpdj"))
;;;;; hpgl  HP7475 and relatives [number of pens] [eject]
;;(define (octave:set-terminal-to-hpgl!) (octave:set-terminal! "hpgl"))
;;;;; hpljii  HP Laserjet series II, [75 100 150 300]
;;(define (octave:set-terminal-to-hpljii!) (octave:set-terminal! "hpljii"))
;;;;; hppj  HP PaintJet and HP3630 [FNT5X9 FNT9X17 FNT13X25]
;;(define (octave:set-terminal-to-hppj!) (octave:set-terminal! "hppj"))
;;;;; imagen  Imagen laser printer
;;(define (octave:set-terminal-to-imagen!) (octave:set-terminal! "imagen"))
;;;;; jpeg  JPEG images using libgd and TrueType fonts
;;(define (octave:set-terminal-to-jpeg!) (octave:set-terminal! "jpeg"))
;;;;; kc_tek40xx  MS-DOS Kermit Tek4010 terminal emulator - color
;;(define (octave:set-terminal-to-kc!) (octave:set-terminal! "kc"))
;;;;; km_tek40xx  MS-DOS Kermit Tek4010 terminal emulator - monochrome
;;(define (octave:set-terminal-to-km!) (octave:set-terminal! "km"))
;;;;; latex  LaTeX picture environment
;;(define (octave:set-terminal-to-latex!) (octave:set-terminal! "latex"))
;;;;; mf  Metafont plotting standard
;;(define (octave:set-terminal-to-mf!) (octave:set-terminal! "mf"))
;;;;; mif  Frame maker MIF 3.00 format
;;(define (octave:set-terminal-to-mif!) (octave:set-terminal! "mif"))
;;;;; mp  MetaPost plotting standard
;;(define (octave:set-terminal-to-mp!) (octave:set-terminal! "mp"))
;;;;; nec_cp6  NEC printer CP6, Epson LQ-800 [monocrome color draft]
;;(define (octave:set-terminal-to-nec!) (octave:set-terminal! "nec"))
;;;;; okidata  OKIDATA 320/321 Standard
;;(define (octave:set-terminal-to-okidata!) (octave:set-terminal! "okidata"))
;;;;; pbm  Portable bitmap [small medium large] [monochrome gray color]
;;(define (octave:set-terminal-to-pbm!) (octave:set-terminal! "pbm"))
;;;;; pcl5  HP Designjet 750C, HP Laserjet III/IV, etc. (many options)
;;(define (octave:set-terminal-to-pcl5!) (octave:set-terminal! "pcl5"))
;;;;; png  PNG images using libgd and TrueType fonts
;;(define (octave:set-terminal-to-png!) (octave:set-terminal! "png"))
;;;;; postscript  PostScript graphics language [mode "fontname" font_size]
;;(define (octave:set-terminal-to-postscript!) (octave:set-terminal! "postscript"))
;;;;; pslatex  LaTeX picture environment with PostScript \specials
;;(define (octave:set-terminal-to-pslatex!) (octave:set-terminal! "pslatex"))
;;;;; pstex  plain TeX with PostScript \specials
;;(define (octave:set-terminal-to-pstex!) (octave:set-terminal! "pstex"))
;;;;; pstricks  LaTeX picture environment with PSTricks macros
;;(define (octave:set-terminal-to-pstricks!) (octave:set-terminal! "pstricks"))
;;;;; qms  QMS/QUIC Laser printer (also Talaris 1200 and others)
;;(define (octave:set-terminal-to-qms!) (octave:set-terminal! "qms"))
;;;;; regis  REGIS graphics language
;;(define (octave:set-terminal-to-regis!) (octave:set-terminal! "regis"))
;;;;; selanar  Selanar
;;(define (octave:set-terminal-to-selanar!) (octave:set-terminal! "selanar"))
;;;;; starc  Star Color Printer
;;(define (octave:set-terminal-to-starc!) (octave:set-terminal! "starc"))
;;;;; svg  W3C Scalable Vector Graphics driver
;;(define (octave:set-terminal-to-svg!) (octave:set-terminal! "svg"))
;;;;; table  Dump ASCII table of X Y [Z] values to output
;;(define (octave:set-terminal-to-table!) (octave:set-terminal! "table"))
;;;;; tandy_60dpi  Tandy DMP-130 series 60-dot per inch graphics
;;(define (octave:set-terminal-to-tandy!) (octave:set-terminal! "tandy"))
;;;;; tek40xx  Tektronix 4010 and others; most TEK emulators
;;(define (octave:set-terminal-to-tek40xx!) (octave:set-terminal! "tek40xx"))
;;;;; tek410x  Tektronix 4106, 4107, 4109 and 420X terminals
;;(define (octave:set-terminal-to-tek410x!) (octave:set-terminal! "tek410x"))
;;;;; texdraw  LaTeX texdraw environment
;;(define (octave:set-terminal-to-texdraw!) (octave:set-terminal! "texdraw"))
;;;;; tgif  TGIF X11 [mode] [x,y] [dashed] ["font" [fontsize]]
;;(define (octave:set-terminal-to-tgif!) (octave:set-terminal! "tgif"))
;;;;; tkcanvas  Tk/Tcl canvas widget [perltk] [interactive]
;;(define (octave:set-terminal-to-tkcanvas!) (octave:set-terminal! "tkcanvas"))
;;;;; tpic  TPIC -- LaTeX picture environment with tpic \specials
;;(define (octave:set-terminal-to-tpic!) (octave:set-terminal! "tpic"))
;;;;; unknown  Unknown terminal type - not a plotting device
;;(define (octave:set-terminal-to-unknown!) (octave:set-terminal! "unknown"))
;;;;; vttek  VT-like tek40xx terminal emulator
;;(define (octave:set-terminal-to-vttek!) (octave:set-terminal! "vttek"))
;;;;; x11  X11 Window System
;;(define (octave:set-terminal-to-x11!) (octave:set-terminal! "x11"))
;;;;; X11  X11 Window System (identical to x11)
;;(define (octave:set-terminal-to-X11!) (octave:set-terminal! "X11"))
;;;;; xlib  X11 Window System (gnulib_x11 dump)
;;(define (octave:set-terminal-to-xlib!) (octave:set-terminal! "xlib"))



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; TODO: __pltopt__ bar, gplot, gsplot,


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; test
;(use srfi-1); (For "iota": in Gambit use your own iota function)
;(octave:start)
;(octave:plot '(1 2 3) '(3 2 1))
;(octave:title "Foo")
;(octave:xlabel "xbar")
;(octave:ylabel "ybar")
;(octave:grid "on")
;(octave:grid "off")
;(octave:semilogx '(1 2 3) '(3 2 1))
;(octave:title "Foo2")
;(octave:semilogy '(1 2 3) '(3 2 1))
;(octave:title "Foo3")
;(octave:figure)
;(octave:loglog '(1 2 1113) '(3 3.4 2.0) '(1 1.5 211.8) '(2 2.3 21.0)  '(1 1.5 222.3) '(1.2 2.4 2222.0))
;(octave:figure)
;(octave:polar (iota 50) (iota 50))
;(octave:title "Rose")
;(octave:save-plot-to "png" "rose.png")
;(octave:figure)
;(octave:bar (iota 5) (iota 5))
;(octave:figure)
;(octave:mesh '((0 1 2 4) (1 2 2 5) (1 3 2 4) (0 2 4 6)))
;(octave:save-plot-to "ps" "foo.ps")
;(octave:errorbar (list 1.1 2.1 3.1 4.1) (list 2 3 2 3) (list .1 .2 .2 .1)  (list .1 .2 .2 .2) "'~>'")
;(octave:errorbar (list 1.1 2.1 3.1 4.1) (list 2 3 2 3) (list .1 .2 .2 .1)  (list .1 .2 .2 .2)  (list .2 .2 .2 .2)  (list .4 .4 .4 .4) "'#~>'")
;(octave:stop)

